@@ -30,7 +30,7 @@ class Tm4jApi(object):
         self.jauth = (self.juser, self.jpass)
         self.zurl = '%s/rest/atm/1.0' % self.jurl
         self.zfolder = zfolder if zfolder else '/Automation'
-        self.zcycle= zcycle if zcycle else os.getenv('TM4J_CYCLE_KEY')
+        self.zcycle = zcycle if zcycle else os.getenv('TM4J_CYCLE_KEY')
         self.session = requests.session()
         self.headers = {
             'Accept': 'application/json',
@@ -38,6 +38,11 @@ class Tm4jApi(object):
         }
 
     def get_environments(self, jira_project=None):
+        """
+        获取环境信息
+        :param jira_project:
+        :return:
+        """
         url = '/'.join([
             self.zurl,
             'environments'
@@ -51,6 +56,29 @@ class Tm4jApi(object):
         pprint(rsp.json())
         return rsp.json()
 
+    def post_environments(self, env_name, env_desc='', jira_project=None):
+        """
+        创建环境
+        :param env_name: 环境名称
+        :param env_desc: 环境说明
+        :param jira_project: jira project key
+        :return:
+        """
+        url = '/'.join([
+            self.zurl,
+            'environments'
+        ])
+        body = {
+            'projectKey': jira_project if jira_project else self.jproject,
+            'name': env_name,
+            'description': env_desc
+        }
+        print('POST', url)
+        rsp = self.session.post(url=url, auth=self.jauth, headers=self.headers, json=body)
+        assert rsp.status_code == 201, '%s\n%s' % (rsp.status_code, rsp.json())
+        pprint(rsp.json())
+        return rsp.json()
+
     def post_case(self, case_name, case_folder=None, jira_project=None):
         """
         创建测试用例
@@ -101,12 +129,13 @@ class Tm4jApi(object):
         else:
             return rsp.json()[0]['key']
 
-    def post_case_result(self, test_result, case_key, cycle_key=None):
+    def post_case_result(self, test_result, case_key, cycle_key=None, run_env=None):
         """
         上传指定执行的测试结果
         :param test_result:
         :param case_key:
         :param cycle_key:
+        :param run_env:
         :return:
         """
         test_cycle_key = cycle_key if cycle_key else self.zcycle
@@ -121,7 +150,7 @@ class Tm4jApi(object):
         ])
         body = {
             'status': test_result['status'].capitalize(),
-            'environment': test_result['env'],
+            'environment': run_env if run_env else '',
             'comment': test_result['comment'],
             # 'executedBy': '',
             'executionTime': int((test_result['endtime'] - test_result['starttime']).total_seconds() * 1000),
@@ -133,12 +162,13 @@ class Tm4jApi(object):
         assert rsp.status_code == 201, 'Status Code: %s\n%s' % (rsp.status_code, rsp.json())
         return rsp.json()
 
-    def post_result(self, test_result, case_key, jira_project=None):
+    def post_result(self, test_result, case_key, jira_project=None, run_env=None):
         """
         上传一个测试结果
         :param test_result:
         :param case_key:
         :param jira_project:
+        :param run_env:
         :return:
         """
         url = '/'.join([
@@ -149,7 +179,7 @@ class Tm4jApi(object):
             'projectKey': jira_project if jira_project else self.jproject,
             'testCaseKey': case_key,
             'status': test_result['status'].capitalize(),
-            'environment': test_result['env'],
+            'environment': run_env if run_env else '',
             'comment': test_result['comment'],
             # 'executedBy': '',
             'executionTime': int((test_result['endtime'] - test_result['starttime']).total_seconds() * 1000),
